package Template::Plugin::DtFormatter::RelativeDate::I18N;

=head1 NAME

Template::Plugin::DtFormatter::RelativeDate::I18N - return finder like relative date.

=cut

our $VERSION = '0.01';

use base qw/Locale::Maketext/;

1;
